@@ -21,7 +21,7 @@ class SMTPEmailBackend(EmailBackend):
         email_message.attach_alternative(message.content, 'text/html')
         for attachment in message.attachments.all():
             email_message.attach(
-                os.path.basename(attachment.file.name),
+                attachment.filename or os.path.basename(attachment.file.name),
                 attachment.file.read().decode('utf-8'),
                 attachment.content_type,
             )
