@@ -115,7 +115,7 @@ class SMSBackend(BaseBackend):
         return settings.SMS_RETRY_SENDING and is_turned_on_sms_batch_sending()
 
 
-def send_template(recipient, slug, context_data, related_objects=None, tag=None):
+def send_template(recipient, slug, context_data, related_objects=None, tag=None, send_immediately=False):
     """
     Helper for building and sending SMS message from a template.
     :param recipient: phone number of the recipient
@@ -125,6 +125,7 @@ def send_template(recipient, slug, context_data, related_objects=None, tag=None)
         relation
     :param tag: string mark that will be saved with the message
     :return: SMS message object or None if template cannot be sent
+    :param send_immediately: publishes the message regardless of the `is_turned_on_batch_sending` result
     """
     return _send_template(
         recipient=recipient,
@@ -133,10 +134,11 @@ def send_template(recipient, slug, context_data, related_objects=None, tag=None)
         related_objects=related_objects,
         tag=tag,
         template_model=get_sms_template_model(),
+        send_immediately=send_immediately
     )
 
 
-def send(recipient, content, related_objects=None, tag=None, **kwargs):
+def send(recipient, content, related_objects=None, tag=None, send_immediately=False, **kwargs):
     """
     Helper for sending SMS message.
     :param recipient: phone number of the recipient
@@ -144,6 +146,7 @@ def send(recipient, content, related_objects=None, tag=None, **kwargs):
     :param related_objects:
     :param tag: string mark that will be saved with the message
     :param kwargs: extra attributes that will be stored with messages
+    :param send_immediately: publishes the message regardless of the `is_turned_on_batch_sending` result
     :return: True if SMS was successfully sent or False if message is in error state
     """
     return _send(
@@ -152,5 +155,6 @@ def send(recipient, content, related_objects=None, tag=None, **kwargs):
         related_objects=related_objects,
         tag=tag,
         message_controller=SMSController(),
+        send_immediately=send_immediately,
         **kwargs
     )
